@@ -10,7 +10,6 @@
 
 #include <limits.h>
 #include <float.h>
-#define GLIB_HAVE_SYS_POLL_H
 
 /* Specifies that GLib's g_print*() functions wrap the
  * system printf functions.  This is useful to know, for example,
@@ -94,18 +93,14 @@ typedef unsigned long guintptr;
 #define G_GINTPTR_MODIFIER      "l"
 #define G_GINTPTR_FORMAT        "li"
 #define G_GUINTPTR_FORMAT       "lu"
-
-#ifdef NeXT /* @#%@! NeXTStep */
-# define g_ATEXIT(proc)	(!atexit (proc))
-#else
-# define g_ATEXIT(proc)	(atexit (proc))
+#ifndef G_DISABLE_DEPRECATED
+#define g_ATEXIT(proc)	(atexit (proc))
+#define g_memmove(dest,src,len) G_STMT_START { memmove ((dest), (src), (len)); } G_STMT_END
 #endif
 
-#define g_memmove(dest,src,len) G_STMT_START { memmove ((dest), (src), (len)); } G_STMT_END
-
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 38
-#define GLIB_MICRO_VERSION 2
+#define GLIB_MINOR_VERSION 40
+#define GLIB_MICRO_VERSION 0
 
 #define G_OS_UNIX
 
@@ -160,6 +155,8 @@ typedef unsigned long guintptr;
 
 #define G_ATOMIC_OP_MEMORY_BARRIER_NEEDED 1
 
+#define G_ATOMIC_LOCK_FREE
+
 #define GINT16_TO_BE(val)	((gint16) (val))
 #define GUINT16_TO_BE(val)	((guint16) (val))
 #define GINT16_TO_LE(val)	((gint16) GUINT16_SWAP_LE_BE (val))
